require "devise_authentication/dependencies"

module DeviseAuthentication
    class Engine < ::Rails::Engine
        isolate_namespace DeviseAuthentication

        config.generators do |g|
            g.test_framework :rspec, :fixture => false
            g.fixture_replacement :factory_girl, :dir => 'spec/factories'
            g.assets false
            g.helper false
        end

        # We are decorating other classes in order to add authentication to it.
        initializer :set_decorator_paths, :before => :load_environment_hook do |app|
            ActiveSupportDecorators.debug = true
            ActiveSupportDecorators.paths << File.join(config.root, 'app/**')

        end

        config.after_initialize do
            # Do some decorating based on a dynamic (configured) module name.
            # Use a initializer and set DeviseAuthentication.frontend_modules = [<ModuleName_As_String>, ...]
            DeviseAuthentication.frontend_modules.each do |module_name|
                module_name.constantize::AuthenticatedController.class_eval do
                    include DeviseAuthentication::Base
                end
            end
        end
    end
end
